@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/ncatted.c,v 1.164 2013/10/05 08:09:29 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/ncatted.c,v 1.175 2013/11/01 00:09:59 pvicente Exp $ */
 
 /* ncatted -- netCDF attribute editor */
 
@@ -98,6 +98,10 @@
    Verify results:
    ncks -C -h ~/foo.nc | m */
 
+#if 1
+#define USE_TRV_API
+#endif
+
 #ifdef HAVE_CONFIG_H
 # include <config.h> /* Autotools tokens */
 #endif /* !HAVE_CONFIG_H */
@@ -156,9 +160,10 @@ main(int argc,char **argv)
   char *fl_pth_lcl=NULL; /* Option l */
   char *opt_crr=NULL; /* [sng] String representation of current long-option name */
   char *sng_cnv_rcd=NULL_CEWI; /* [sng] strtol()/strtoul() return code */
+  char trv_pth[]="/"; /* [sng] Root path of traversal tree */
 
-  const char * const CVS_Id="$Id: ncatted.c,v 1.164 2013/10/05 08:09:29 zender Exp $"; 
-  const char * const CVS_Revision="$Revision: 1.164 $";
+  const char * const CVS_Id="$Id: ncatted.c,v 1.175 2013/11/01 00:09:59 pvicente Exp $"; 
+  const char * const CVS_Revision="$Revision: 1.175 $";
   const char * const opt_sht_lst="Aa:D:hl:Oo:p:Rr-:";
 
 #if defined(__cplusplus) || defined(PGI_CC)
@@ -173,8 +178,6 @@ main(int argc,char **argv)
 
   int abb_arg_nbr=0;
   int fl_nbr=0;
-  int idx;
-  int idx_var;
   int nbr_aed=0; /* Option a. NB: nbr_var_aed gets incremented */
   int nbr_var_fl;
   int nc_id;  
@@ -212,7 +215,7 @@ main(int argc,char **argv)
     {"append",no_argument,0,'A'},
     {"attribute",required_argument,0,'a'},
     {"debug",required_argument,0,'D'},
-    {"dbg_lvl",required_argument,0,'D'},
+    {"nco_dbg_lvl",required_argument,0,'D'},
     {"history",no_argument,0,'h'},
     {"hst",no_argument,0,'h'},
     {"local",required_argument,0,'l'},
@@ -236,8 +239,8 @@ main(int argc,char **argv)
   ddra_info.tmr_flg=nco_tmr_mtd;
   cmd_ln=nco_cmd_ln_sng(argc,argv);
 
-  /* Get program name and set program enum (e.g., prg=ncra) */
-  prg_nm=prg_prs(argv[0],&prg);
+  /* Get program name and set program enum (e.g., nco_prg_id=ncra) */
+  nco_prg_nm=nco_prg_prs(argv[0],&nco_prg_id);
 
   /* Parse command line arguments */
   while(1){
@@ -278,7 +281,7 @@ main(int argc,char **argv)
       nbr_aed++;
       break;
     case 'D': /* Debugging level. Default is 0. */
-      dbg_lvl=(unsigned short int)strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+      nco_dbg_lvl=(unsigned short int)strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
       if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtoul",sng_cnv_rcd);
       break;
     case 'h': /* Toggle appending to history global attribute */
@@ -311,11 +314,11 @@ main(int argc,char **argv)
       nco_exit(EXIT_SUCCESS);
       break;
     case '-': /* Long options are not allowed */
-      (void)fprintf(stderr,"%s: ERROR Long options are not available in this build. Use single letter options instead.\n",prg_nm_get());
+      (void)fprintf(stderr,"%s: ERROR Long options are not available in this build. Use single letter options instead.\n",nco_prg_nm_get());
       nco_exit(EXIT_FAILURE);
       break;
     default: /* Print proper usage */
-      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command accordingly.\n",prg_nm_get());
+      (void)fprintf(stdout,"%s ERROR in command-line syntax/options. Please reformulate command accordingly.\n",nco_prg_nm_get());
       (void)nco_usg_prn();
       nco_exit(EXIT_FAILURE);
     } /* end switch */
@@ -327,12 +330,12 @@ main(int argc,char **argv)
   if(fl_out) FL_OUT_NEW=True; else fl_out=(char *)strdup(fl_lst_in[0]);
 
   if(nbr_aed == 0){
-    (void)fprintf(stdout,"%s: ERROR must specify an attribute to edit\n",prg_nm);
+    (void)fprintf(stdout,"%s: ERROR must specify an attribute to edit\n",nco_prg_nm);
     nco_usg_prn();
     nco_exit(EXIT_FAILURE);
   } /* end if */ 
 
-  if(dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: DEBUG attribute assumed to hold missing data is named \"%s\"\n",prg_nm_get(),nco_mss_val_sng_get());
+  if(nco_dbg_lvl_get() >= nco_dbg_var) (void)fprintf(stdout,"%s: DEBUG attribute assumed to hold missing data is named \"%s\"\n",nco_prg_nm_get(),nco_mss_val_sng_get());
 
   /* Make uniform list of user-specified attribute edit structures */
   if(nbr_aed > 0) aed_lst=nco_prs_aed_lst(nbr_aed,aed_arg);
@@ -358,7 +361,7 @@ main(int argc,char **argv)
   } /* end if FL_OUT_NEW */
 
   /* Open file. Writing must be enabled and file should be in define mode for renaming */
-  /*  if(dbg_lvl == 8) md_open|=NC_SHARE;*/
+  /*  if(nco_dbg_lvl == 8) md_open|=NC_SHARE;*/
   if(RAM_OPEN) md_open=NC_WRITE|NC_DISKLESS; else md_open=NC_WRITE;
   rcd+=nco_fl_open(fl_out,md_open,&bfr_sz_hnt,&nc_id);
   (void)nco_redef(nc_id);
@@ -366,21 +369,29 @@ main(int argc,char **argv)
   /* Get number of variables in file */
   (void)nco_inq(nc_id,(int *)NULL,&nbr_var_fl,(int *)NULL,(int *)NULL);
 
+ /* Initialize traversal table */ 
+  trv_tbl_init(&trv_tbl); 
+
+  /* Construct GTT (Group Traversal Table) */
+  (void)nco_bld_trv_tbl(nc_id,trv_pth,(int)0,NULL,(int)0,NULL,False,False,NULL,(int)0,NULL,(int) 0,False,False,False,True,trv_tbl);
+
   /* Timestamp end of metadata setup and disk layout */
   rcd+=nco_ddra((char *)NULL,(char *)NULL,&ddra_info);
   ddra_info.tmr_flg=nco_tmr_rgl;
 
-  for(idx=0;idx<nbr_aed;idx++){
+
+#ifndef USE_TRV_API
+  for(int idx=0;idx<nbr_aed;idx++){
     if(aed_lst[idx].var_nm == NULL){
       /* Variable name is blank so edit same attribute for all variables ... */
-      for(idx_var=0;idx_var<nbr_var_fl;idx_var++) (void)nco_aed_prc(nc_id,idx_var,aed_lst[idx]);
+      for(int idx_var=0;idx_var<nbr_var_fl;idx_var++) (void)nco_aed_prc(nc_id,idx_var,aed_lst[idx]);
     }else if(strpbrk(aed_lst[idx].var_nm,".*^$\\[]()<>+?|{}")){
       /* Variable name contains a "regular expression" (rx) ... */
       int xtr_nbr=1;
       nm_id_sct *xtr_lst=NULL;
       xtr_lst=nco_var_lst_mk(nc_id,nbr_var_fl,&aed_lst[idx].var_nm,False,False,&xtr_nbr);
       /* Edit attribute for each matching variable */
-      for(idx_var=0;idx_var<xtr_nbr;idx_var++) (void)nco_aed_prc(nc_id,xtr_lst[idx_var].id,aed_lst[idx]);
+      for(int idx_var=0;idx_var<xtr_nbr;idx_var++) (void)nco_aed_prc(nc_id,xtr_lst[idx_var].id,aed_lst[idx]);
       /* Free Extraction list  */
       xtr_lst=nco_nm_id_lst_free(xtr_lst,xtr_nbr);
     }else if(!strcasecmp(aed_lst[idx].var_nm,"global")){
@@ -393,6 +404,39 @@ main(int argc,char **argv)
       (void)nco_aed_prc(nc_id,aed_lst[idx].id,aed_lst[idx]);
     } /* end var_nm */
   } /* end loop over idx */
+#else /* USE_TRV_API */
+
+  /* Loop input names */
+  for(int idx_aed=0;idx_aed<nbr_aed;idx_aed++){
+    if(aed_lst[idx_aed].var_nm == NULL){
+      /* Variable name is blank so edit same attribute for all variables ... */
+      (void)nco_aed_prc_var(nc_id,aed_lst[idx_aed],trv_tbl);
+    }else if(strpbrk(aed_lst[idx_aed].var_nm,".*^$\\[]()<>+?|{}")){
+      /* Variable name contains a "regular expression" (rx) ... */
+      trv_tbl_sct *trv_tbl_rx;
+      char **var_lst_in; /* I [sng] User-specified list of variables */
+      int var_lst_in_nbr; /* I [nbr] Number of variables in list */
+      var_lst_in=nco_lst_prs_2D(aed_lst[idx_aed].var_nm,",",&var_lst_in_nbr);
+      trv_tbl_init(&trv_tbl_rx); 
+      /* Construct GTT (Group Traversal Table) */
+      (void)nco_bld_trv_tbl(nc_id,trv_pth,(int)0,NULL,(int)0,NULL,False,False,NULL,(int)0,var_lst_in,var_lst_in_nbr,False,False,False,False,trv_tbl_rx);
+      /* Edit same attribute for all variables ... */
+      (void)nco_aed_prc_var_xtr(nc_id,aed_lst[idx_aed],trv_tbl_rx);
+      trv_tbl_free(trv_tbl_rx);
+      var_lst_in=nco_sng_lst_free(var_lst_in,var_lst_in_nbr);
+    }else if(!strcasecmp(aed_lst[idx_aed].var_nm,"group")){
+      /* Variable name indicates a group attribute ... */
+      (void)nco_aed_prc_grp(nc_id,aed_lst[idx_aed],trv_tbl);
+    }else if(!strcasecmp(aed_lst[idx_aed].var_nm,"global")){
+      /* Variable name indicates a global attribute ... */
+      (void)nco_aed_prc_glb(nc_id,aed_lst[idx_aed],trv_tbl);
+    }else{ 
+      /* Variable is a normal variable ... */
+      /* Inquire if any variable matches (absolute, relative)  */
+      (void)nco_aed_prc_var_nm(nc_id,aed_lst[idx_aed],trv_tbl);
+    } /* end var_nm */
+  } /* Loop input names */
+#endif /* USE_TRV_API */
 
   /* Catenate the timestamped command line to the "history" global attribute */
   if(HISTORY_APPEND) (void)nco_hst_att_cat(nc_id,cmd_ln);
@@ -402,7 +446,7 @@ main(int argc,char **argv)
     (void)nco_enddef(nc_id);
   }else{
     (void)nco__enddef(nc_id,hdr_pad);
-    if(dbg_lvl >= nco_dbg_scl) (void)fprintf(stderr,"%s: INFO Padding header with %lu extra bytes\n",prg_nm_get(),(unsigned long)hdr_pad);
+    if(nco_dbg_lvl >= nco_dbg_scl) (void)fprintf(stderr,"%s: INFO Padding header with %lu extra bytes\n",nco_prg_nm_get(),(unsigned long)hdr_pad);
   } /* hdr_pad */
 
   /* Close the open netCDF file */
@@ -414,8 +458,8 @@ main(int argc,char **argv)
   /* Clean memory unless dirty memory allowed */
   if(flg_cln){
     /* ncatted-specific memory */
-    for(idx=0;idx<nbr_aed;idx++) aed_arg[idx]=(char *)nco_free(aed_arg[idx]);
-    for(idx=0;idx<nbr_aed;idx++){
+    for(int idx=0;idx<nbr_aed;idx++) aed_arg[idx]=(char *)nco_free(aed_arg[idx]);
+    for(int idx=0;idx<nbr_aed;idx++){
       if(aed_lst[idx].att_nm) aed_lst[idx].att_nm=(char *)nco_free(aed_lst[idx].att_nm);
       if(aed_lst[idx].var_nm) aed_lst[idx].var_nm=(char *)nco_free(aed_lst[idx].var_nm);
       aed_lst[idx].val.vp=(void *)nco_free(aed_lst[idx].val.vp);
