@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.411 2013/10/16 17:11:09 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco.h,v 1.426 2013/11/06 01:37:17 pvicente Exp $ */
 
 /* Purpose: netCDF Operator (NCO) definitions */
 
@@ -20,6 +20,7 @@
 
 /* Personal headers */
 #include "nco_typ.h" /* Type definitions, opaque types */
+#include "nco_uthash.h" /* Hash table functionality */
 
   /* C pre-processor macros for instantiating variable values with string tokens
      Macros for token pasting described at http://www.parashift.com/c++-faq-lite
@@ -107,6 +108,7 @@ extern "C" {
 #define NCO_BYT_PER_KB 1024UL
 #define NCO_BYT_PER_MB 1048576UL
 #define NCO_BYT_PER_GB 1073741824UL
+#define NCO_BYT_PER_TB 1099511627776UL
 
   /* netcdf.h NC_GLOBAL is, strictly, the variable ID for global attributes
      NCO_REC_DMN_UNDEFINED is dimension ID of record dimension iff record dimension is undefined
@@ -131,10 +133,13 @@ extern "C" {
 #define NCO_LST_GRP 0
 
   /* Debugging level that quiets all non-requested informational messages
-     This value is compared against user-selected dbg_lvl 
-     Running operators with --quiet automatically sets dbg_lvl=NCO_DBG_QUIET */
+     This value is compared against user-selected nco_dbg_lvl 
+     Running operators with --quiet automatically sets nco_dbg_lvl=NCO_DBG_QUIET */
 #define NCO_DBG_QUIET 0
 
+  /* Find traversal table objects via hash table rather than bruit-force strcmp() search */
+  //#define NCO_HSH_TRV_OBJ 1
+
   /* NCO_MSS_VAL_SNG names attribute whose value is "skipped" by arithmetic, aka the missing value attribute
      Attribute name should be either "missing_value" or "_FillValue" */
 #ifndef NCO_MSS_VAL_SNG
@@ -157,9 +162,9 @@ extern "C" {
   /* Prototype global functions before defining them in next block */
   char *nco_mss_val_sng_get(void); /* [sng] Missing value attribute name */
   char *nco_not_mss_val_sng_get(void); /* [sng] Not missing value attribute name */
-  char *prg_nm_get(void);
-  int prg_get(void);
-  unsigned short dbg_lvl_get(void);
+  char *nco_prg_nm_get(void);
+  int nco_prg_id_get(void);
+  unsigned short nco_dbg_lvl_get(void);
   unsigned short nco_hdf_cnv_get(void);
   unsigned short nco_mrd_cnv_get(void);
   unsigned short nco_rth_cnv_get(void);
@@ -169,14 +174,14 @@ extern "C" {
   
   /* Tokens and variables with scope limited to main.c, and global variables allocated here */
   
-  int prg; /* [enm] Program ID */
-  int prg_get(void){return prg;} /* [enm] Program ID */
+  int nco_prg_id; /* [enm] Program ID */
+  int nco_prg_id_get(void){return nco_prg_id;} /* [enm] Program ID */
   
-  char *prg_nm; /* [sng] Program name */
-  char *prg_nm_get(void){return prg_nm;} /* [sng] Program name */
+  char *nco_prg_nm; /* [sng] Program name */
+  char *nco_prg_nm_get(void){return nco_prg_nm;} /* [sng] Program name */
   
-  unsigned short dbg_lvl=0; /* [enm] Debugging level */
-  unsigned short dbg_lvl_get(void){return dbg_lvl;} /* [enm] Debugging level */
+  unsigned short nco_dbg_lvl=0; /* [enm] Debugging level */
+  unsigned short nco_dbg_lvl_get(void){return nco_dbg_lvl;} /* [enm] Debugging level */
 
   unsigned short nco_hdf_cnv=0; /* [enm] HDF convention */
   unsigned short nco_hdf_cnv_get(void){return nco_hdf_cnv;} /* [enm] HDF convention */
@@ -353,12 +358,11 @@ extern "C" {
 
 #define TRV_MAP_SIZE NC_MAX_DIMS
 
-  enum prg{ /* [enm] Key value for all netCDF operators */
+  enum nco_prg_id{ /* [enm] Key value for all netCDF operators */
     ncap,
     ncatted,
     ncbo,
-    ncea,
-    ncga,
+    ncea, 
     ncecat,
     ncflint,
     ncks,
@@ -366,8 +370,10 @@ extern "C" {
     ncra,
     ncrcat,
     ncrename,
-    ncwa
-  }; /* end prg enum */
+    ncwa,
+    nces, /* 20131018: Potential new operator */
+    ncmv /* 20131018: Potential new operator */
+  }; /* end nco_prg_id enum */
   
   enum nco_dbg_typ_enm{ /* [enm] Debugging levels */
     /* List in increasing levels of verbosity */
@@ -768,11 +774,9 @@ extern "C" {
     crd_sct *crd;            /* [sct] Pointer to coordinate variable if any */
     dmn_trv_sct *ncd;        /* [sct] Pointer to non-coordinate dimension if any */
     int dmn_id;              /* [ID] Dimension ID; same as dmn_trv_sct.id from nc_inq_vardimid() */
-
     /* Following are members only used by transformation operators (non-ncks) */
     nco_bool flg_dmn_avg;    /* [flg] Diferentiate between dimensions to average or keep for this variable (ncwa) */  
     nco_bool flg_rdd;        /* [flg] Retain dimension as degenerate (size 1) (ncwa) */  
-
   } var_dmn_sct; 
 
   /* Processing type enumerator */
@@ -822,14 +826,21 @@ extern "C" {
     nco_bool flg_vsg;                 /* [flg] Variable selected because group matches */
     nco_bool flg_xcl;                 /* [flg] Object matches exclusion criteria */
     nco_bool flg_xtr;                 /* [flg] Extract object */ 
-
-    /* Following are members only used by transformation operators (non-ncks) (For variables only) */
+    /* Following are members only used by transformation operators (non-ncks)  */
     prc_typ_enm enm_prc_typ;          /* [enm] Processing type enumerator */
     nc_type var_typ_out;              /* [enm] NetCDF type in output file (ncflint) (ncpdq) */  
     int dmn_idx_out_in[NC_MAX_DIMS];  /* [nbr] Dimension correspondence, output->input (ncpdq); output of nco_var_dmn_rdr_mtd() */
     nco_bool dmn_rvr_in[NC_MAX_DIMS]; /* [flg] Reverse dimensions (ncpdq) */
     nco_bool flg_rdr;                 /* [flg] Variable has dimensions to re-order (ncpdq) */ 
     char *rec_dmn_nm_out;             /* [sng] Record dimension name, re-ordered (ncpdq) (used as flag also for re-defined record dimension)*/
+    char *grp_nm_fll_prn;             /* [sng] (nces) Parent group full name */
+    /* Good hash, dude */
+    UT_hash_handle hh;                /* [sct] Handle for hash table */
+    char *hsh_key;                    /* [sng] Hash key (must be unique!) */
+    nco_bool flg_nsm_prn;             /* [flg] (nces) Group is, or variable is in, ensemble parent group */
+    nco_bool flg_nsm_mbr;             /* [flg] (nces) Group is, or variable is in, ensemble member group */
+    nco_bool flg_nsm_tpl;             /* [flg] Group is, or variable is in, template member group */
+    char *nsm_nm;                     /* [sng] (nces) Ensemble parent group name i.e., full path to ensemble parent */ 
   } trv_sct;
 
   /* Fill actual value of dmn_sct structure in nco_dmn_fll()
@@ -855,6 +866,13 @@ extern "C" {
     struct dmn_sct_tag *xrf; /* [sct] Cross-reference to associated dimension structure (usually the structure for dimension on output) */
   } dmn_sct; /* end dmn_sct_tag */
 
+  /* Ensemble (nces) */
+  typedef struct{
+    char *grp_nm_fll_prn;   /* [sng] Parent group full name (key for ensemble) */
+    int mbr_nbr;            /* [nbr] Number of members of ensemble (i.e., number in this ensemble in this file) */ 
+    char **mbr_nm;          /* [sng] List of member group names (size is mbr_nbr) */ 
+  } nsm_sct; 
+
   /* GTT (Group Traversal Table) structure contains two lists
      1) lst: All objects (variables and groups) in file tree (HDF5 model)
      2) lst_dmn: All unique dimensions (in groups) in file tree (netCDF addition to HDF5) */
@@ -864,13 +882,13 @@ extern "C" {
     unsigned int nbr;       /* [nbr] Number of trv_sct elements */   
     dmn_trv_sct *lst_dmn;   /* [sct] Array of dmn_trv_sct */
     unsigned int nbr_dmn;   /* [nbr] Number of dmn_trv_sct elements */
-
-    /* Members used only by transformation operators (non-ncks) */
+    trv_sct *hsh;           /* [hsh] Hash table of all trv_sct objects */
     dmn_sct *dmn_dgn;       /* [sct] (ncwa) Degenerate dimensions */
     int nbr_dmn_dgn;        /* [sct] (ncwa) Number of degenerate dimensions (size of above array) */
-
     lmt_sct **lmt_rec;      /* [sct] (ncra) Record dimensions */
     int nbr_rec;            /* [sct] (ncra) Number of record dimensions (size of above array) */
+    int nsm_nbr;            /* [nbr] (nces) Number of ensembles (i.e., number in first file) */ 
+    nsm_sct *nsm;           /* [lst] (nces) List of ensembles (size is nsm_nbr) */ 
   } trv_tbl_sct;
  
   /* GPE duplicate name check structure */
@@ -891,7 +909,7 @@ extern "C" {
 
   /* Common variable names; common defined as same absolute path in 2 files */
   typedef struct{		
-    char *var_nm_fll;            /* [sng] Full path of variable */
+    char *var_nm_fll;            /* [sng] Full path of variable (can be relative) */
     nco_bool flg_in_fl[2];       /* [flg] Is this name in each file?; files are [0] and [1] */
   } nco_cmn_t;
 
