@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_ctl.h,v 1.44 2013/01/13 06:07:47 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_ctl.h,v 1.46 2013/10/22 03:03:45 zender Exp $ */
 
 /* Purpose: Program flow control functions */
 
@@ -54,16 +54,16 @@ nco_exit_gracefully(void); /* [fnc] Clean up timers, file descriptors, memory, t
 
 nco_bool /* [flg] Program does arithmetic */
 nco_is_rth_opr /* [fnc] Query whether program does arithmetic */
-(const int prg_id); /* [enm] Program ID */
+(const int nco_prg_id); /* [enm] Program ID */
 
 nco_bool /* [flg] Program does arithmetic and preserves rank */
 nco_is_sz_rnk_prv_rth_opr /* [fnc] Is program size and rank-preserving arithmetic operator? */
-(const int prg_id, /* I [enm] Program ID */
+(const int nco_prg_id, /* I [enm] Program ID */
  const int nco_pck_plc); /* I [enm] Packing policy */
 
 nco_bool /* [flg] Program is multi-file operator */
 nco_is_mfo /* [fnc] Query whether program is multi-file operator */
-(const int prg_id); /* [enm] Program ID */
+(const int nco_prg_id); /* [enm] Program ID */
 
 int /* O [rcd] Return code */
 nco_ddra /* [fnc] Count operations */
@@ -87,9 +87,9 @@ const char * /* O [sng] Mnemonic that describes current NCO version */
 nco_nmn_get(void); /* [fnc] Return mnemonic that describes current NCO version */
 
 char * /* O [sng] nm_in stripped of any path (i.e., program name stub) */ 
-prg_prs /* [fnc] Strip program name to stub and return program ID */
+nco_prg_prs /* [fnc] Strip program name to stub and set program ID */
 (const char * const nm_in, /* I [sng] Name of program, i.e., argv[0] (may include path prefix) */
- int * const prg_lcl); /* O [enm] Enumerated number corresponding to nm_in */
+ int * const nco_prg_lcl); /* O [enm] Enumerated number corresponding to nm_in */
 
 void 
 nco_usg_prn(void); /* [fnc] Print correct program usage */
