@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.c,v 1.217 2013/09/22 03:47:30 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.c,v 1.235 2013/11/06 01:37:17 pvicente Exp $ */
 
 /* Purpose: netCDF4 traversal storage */
 
@@ -11,7 +11,6 @@
 
 /* This file contains the API for low level group data structures:
    Group Traversal Table (GTT): functions prefixed with "trv_tbl_"
-   Group Dimension Map (GDM): functions prefixed with "trv_map_"
    It does not include any netCDF API calls */
 
 #include "nco_grp_trv.h" /* Group traversal */
@@ -38,6 +37,10 @@ trv_tbl_init                           /* [fnc] GTT initialize */
   tb->nbr_rec=0;
   tb->lmt_rec=NULL;
 
+  /* Ensembles */
+  tb->nsm_nbr=0;
+  tb->nsm=NULL;
+
   *tbl=tb;
 } /* trv_tbl_init() */
  
@@ -50,7 +53,10 @@ trv_tbl_free                           /* [fnc] GTT free memory */
   for(unsigned idx=0;idx<tbl->nbr;idx++){
     tbl->lst[idx].nm_fll=(char *)nco_free(tbl->lst[idx].nm_fll);
     tbl->lst[idx].grp_nm_fll=(char *)nco_free(tbl->lst[idx].grp_nm_fll);
+    tbl->lst[idx].grp_nm_fll_prn=(char *)nco_free(tbl->lst[idx].grp_nm_fll_prn);
+    tbl->lst[idx].nsm_nm=(char *)nco_free(tbl->lst[idx].nsm_nm);
     tbl->lst[idx].rec_dmn_nm_out=(char *)nco_free(tbl->lst[idx].rec_dmn_nm_out);
+    tbl->lst[idx].hsh_key=(char *)nco_free(tbl->lst[idx].hsh_key);
 
     /* Dimensions */
     for(int dmn_idx=0;dmn_idx<tbl->lst[idx].nbr_dmn;dmn_idx++){
@@ -59,7 +65,7 @@ trv_tbl_free                           /* [fnc] GTT free memory */
       tbl->lst[idx].var_dmn[dmn_idx].grp_nm_fll=(char *)nco_free(tbl->lst[idx].var_dmn[dmn_idx].grp_nm_fll);
 
       /* Coordinate structure */ 
-      if (tbl->lst[idx].var_dmn[dmn_idx].crd) {
+      if(tbl->lst[idx].var_dmn[dmn_idx].crd){
         tbl->lst[idx].var_dmn[dmn_idx].crd->crd_nm_fll=(char *)nco_free(tbl->lst[idx].var_dmn[dmn_idx].crd->crd_nm_fll);
         tbl->lst[idx].var_dmn[dmn_idx].crd->dmn_nm_fll=(char *)nco_free(tbl->lst[idx].var_dmn[dmn_idx].crd->dmn_nm_fll);
         tbl->lst[idx].var_dmn[dmn_idx].crd->crd_grp_nm_fll=(char *)nco_free(tbl->lst[idx].var_dmn[dmn_idx].crd->crd_grp_nm_fll);
@@ -85,9 +91,8 @@ trv_tbl_free                           /* [fnc] GTT free memory */
     tbl->lst_dmn[dmn_idx].grp_nm_fll=(char *)nco_free(tbl->lst_dmn[dmn_idx].grp_nm_fll);
     tbl->lst_dmn[dmn_idx].lmt_msa.dmn_nm=(char *)nco_free(tbl->lst_dmn[dmn_idx].lmt_msa.dmn_nm);
 
-    for(int lmt_idx=0;lmt_idx<tbl->lst_dmn[dmn_idx].lmt_msa.lmt_dmn_nbr;lmt_idx++){
+    for(int lmt_idx=0;lmt_idx<tbl->lst_dmn[dmn_idx].lmt_msa.lmt_dmn_nbr;lmt_idx++)
       tbl->lst_dmn[dmn_idx].lmt_msa.lmt_dmn[lmt_idx]=nco_lmt_free(tbl->lst_dmn[dmn_idx].lmt_msa.lmt_dmn[lmt_idx]);
-    }
 
     /* Total number of coordinate variables for this dimension */
     int crd_nbr=tbl->lst_dmn[dmn_idx].crd_nbr;
@@ -101,9 +106,8 @@ trv_tbl_free                           /* [fnc] GTT free memory */
 
       tbl->lst_dmn[dmn_idx].crd[crd_idx]->lmt_msa.dmn_nm=(char *)nco_free(tbl->lst_dmn[dmn_idx].crd[crd_idx]->lmt_msa.dmn_nm);
 
-      for(int lmt_idx=0;lmt_idx<tbl->lst_dmn[dmn_idx].crd[crd_idx]->lmt_msa.lmt_dmn_nbr;lmt_idx++){
+      for(int lmt_idx=0;lmt_idx<tbl->lst_dmn[dmn_idx].crd[crd_idx]->lmt_msa.lmt_dmn_nbr;lmt_idx++)
         tbl->lst_dmn[dmn_idx].crd[crd_idx]->lmt_msa.lmt_dmn[lmt_idx]=nco_lmt_free(tbl->lst_dmn[dmn_idx].crd[crd_idx]->lmt_msa.lmt_dmn[lmt_idx]);
-      }  
 
       tbl->lst_dmn[dmn_idx].crd[crd_idx]=(crd_sct *)nco_free(tbl->lst_dmn[dmn_idx].crd[crd_idx]);
     }  /* Coordinate structures */
@@ -116,13 +120,22 @@ trv_tbl_free                           /* [fnc] GTT free memory */
   /* Members used only by transformation operators (non-ncks) */
 
   /* (ncra) Record dimensions */
-  for(int idx=0;idx<tbl->nbr_rec;idx++){
+  for(int idx=0;idx<tbl->nbr_rec;idx++)
     tbl->lmt_rec[idx]=nco_lmt_free(tbl->lmt_rec[idx]);
-  }
 
   /* (ncwa) Degenerate dimensions */
   tbl->dmn_dgn=(dmn_sct *)nco_free(tbl->dmn_dgn); 
 
+  /* Ensembles */
+  for(int idx_nsm=0;idx_nsm<tbl->nsm_nbr;idx_nsm++){
+    tbl->nsm[idx_nsm].grp_nm_fll_prn=(char *)nco_free(tbl->nsm[idx_nsm].grp_nm_fll_prn);
+    for(int idx_nm=0;idx_nm<tbl->nsm[idx_nsm].mbr_nbr;idx_nm++){
+      tbl->nsm[idx_nsm].mbr_nm[idx_nm]=(char *)nco_free(tbl->nsm[idx_nsm].mbr_nm[idx_nm]);
+    }
+    tbl->nsm[idx_nsm].mbr_nm=(char **)nco_free(tbl->nsm[idx_nsm].mbr_nm);
+  }
+  
+
   tbl=(trv_tbl_sct *)nco_free(tbl);
 } /* end trv_tbl_free() */
 
@@ -199,7 +212,7 @@ trv_tbl_prn_flg_mch                  /* [fnc] Print table items that have .flg_m
     trv_obj=trv_tbl->lst[tbl_idx];
     if((trv_obj.nco_typ == obj_typ) && trv_obj.flg_mch) (void)fprintf(stdout,"nm_fll=%s\n",trv_obj.nm_fll);
   } /* end loop over trv_tbl */
-}/* end trv_tbl_prn_flg_mch() */
+} /* end trv_tbl_prn_flg_mch() */
 
 void                          
 trv_tbl_prn                          /* [fnc] Print table with -z */
@@ -229,11 +242,18 @@ trv_tbl_var_nm_fll                    /* [fnc] Return object from full name key
 (const char * const var_nm_fll,       /* I [sng] Variable name to find */
  const trv_tbl_sct * const trv_tbl)   /* I [sct] Traversal table */
 {
+  /* Purpose: Return object with given full name */
+
+#ifdef NCO_HSH_TRV_OBJ
+  trv_sct *trv_obj; /* [sct] GTT object structure */
+  HASH_FIND_STR(trv_tbl->hsh,var_nm_fll,trv_obj);
+  return trv_obj;
+#else /* !NCO_HSH_TRV_OBJ */
   for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++)
-    if(trv_tbl->lst[uidx].nco_typ == nco_obj_typ_var && !strcmp(var_nm_fll,trv_tbl->lst[uidx].nm_fll))
-      return &trv_tbl->lst[uidx];
+    if(trv_tbl->lst[uidx].nco_typ == nco_obj_typ_var && !strcmp(var_nm_fll,trv_tbl->lst[uidx].nm_fll)) return &trv_tbl->lst[uidx];
 
   return NULL;
+#endif /* !NCO_HSH_TRV_OBJ */
 
 } /* trv_tbl_var_nm_fll() */
 
@@ -242,8 +262,15 @@ trv_tbl_mrk_xtr                       /* [fnc] Mark extraction flag in table for
 (const char * const var_nm_fll,       /* I [sng] Variable name to find */
  const trv_tbl_sct * const trv_tbl)   /* I [sct] Traversal table */
 {
+
+#ifdef NCO_HSH_TRV_OBJ
+  trv_sct *trv_obj; /* [sct] GTT object structure */
+  HASH_FIND_STR(trv_tbl->hsh,var_nm_fll,trv_obj);
+  if(trv_obj) trv_obj->flg_xtr=True;
+#else /* !NCO_HSH_TRV_OBJ */
   for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++)
     if(!strcmp(var_nm_fll,trv_tbl->lst[uidx].nm_fll)) trv_tbl->lst[uidx].flg_xtr=True;
+#endif /* !NCO_HSH_TRV_OBJ */
 
   return;
 } /* end trv_tbl_mrk_xtr() */
@@ -273,18 +300,14 @@ trv_tbl_prn_xtr                        /* [fnc] Print extraction flag of travers
   int nbr_flg=0;
 
   /* Loop table */
-  for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++){
-    trv_sct trv=trv_tbl->lst[uidx];
-    if(trv.flg_xtr) nbr_flg++;
-  } /* Loop table */
+  for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++)
+    if(trv_tbl->lst[uidx].flg_xtr) nbr_flg++;
 
-  (void)fprintf(stdout,"%s: INFO %s reports <%d> objects with extraction flag (flg_xtr) set:\n",prg_nm_get(),fnc_nm,nbr_flg); 
+  (void)fprintf(stdout,"%s: INFO %s reports <%d> objects with extraction flag (flg_xtr) set:\n",nco_prg_nm_get(),fnc_nm,nbr_flg); 
   
   /* Loop table */
-  for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++){
-    trv_sct trv=trv_tbl->lst[uidx];
-    if(trv.flg_xtr) (void)fprintf(stdout,"[%d] %s\n",idx++,trv.nm_fll); 
-  }/* Loop table */
+  for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++)
+    if(trv_tbl->lst[uidx].flg_xtr) (void)fprintf(stdout,"[%d] %s\n",idx++,trv_tbl->lst[uidx].nm_fll); 
 
 } /* end trv_tbl_prn_xtr() */
 
@@ -313,25 +336,23 @@ trv_tbl_mch                            /* [fnc] Match 2 tables (find common obje
 (trv_tbl_sct * const trv_tbl_1,        /* I/O [sct] GTT (Group Traversal Table) */
  trv_tbl_sct * const trv_tbl_2,        /* I/O [sct] GTT (Group Traversal Table) */
  nco_cmn_t **cmn_lst,                  /* I/O [sct] List of common names */
- int * nbr_cmn_nm)                     /* I/O [nbr] Number of common names entries */
+ int * nbr_cmn_nm)                     /* I/O [nbr] Number of common names */
 {
-  /* Purpose: Find common objects; the algorithm used for this search is the
-  *  cosequential match algorithm and is described in
-  *  Folk, Michael; Zoellick, Bill. (1992). File Structures. Addison-Wesley.
-  *
-  * Compare 2 ordered lists of names:
-  *  if Name(1) is less than Name(2), read the next name from List 1; this is done by incrementing a current index
-  *  if Name(1) is greater than Name(2), read the next name from List 2
-  *  if the names are the same, read the next names from the two lists 
-  * 
-  * Used in ncbo; ncbo performs binary operations on variables in file 1 and the corresponding variables
-  * (those with the same name) in file 2 and stores the results in file 3.
-  * This function detects common absolute names in tables 1 and 2 and does the ncbo binary operation on it
-  *
-  */
-
+  /* Purpose: Find common objects. 
+     Use cosequential match algorithm described in
+     Folk, Michael; Zoellick, Bill. (1992). File Structures. Addison-Wesley.
+     
+     Compare 2 ordered lists of names:
+     if Name(1) is less than Name(2), read next name from List 1; this is done by incrementing current index
+     if Name(1) is greater than Name(2), read next name from List 2
+     if names are identical, read next names from both lists 
+     
+     Used in ncbo; ncbo performs binary operations on variables in file 1 and matching variables
+     (those with the same name) in file 2 and stores results in file 3.
+     This function detects common absolute names in tables 1 and 2 and does ncbo binary operation */
+  
   const char fnc_nm[]="trv_tbl_mch()"; /* [sng] Function name */
-
+  
   int idx_lst;                   /* [idx] Current position in common List */ 
   int idx_tbl_1;                 /* [idx] Current position in List 1 */ 
   int idx_tbl_2;                 /* [idx] Current position in List 2 */ 
@@ -340,27 +361,34 @@ trv_tbl_mch                            /* [fnc] Match 2 tables (find common obje
   int nco_cmp;                   /* [nbr] Return value of strcmp() */ 
 
   nco_bool flg_more_names_exist; /* [flg] Are there more names to process? */
-  nco_bool flg_in_fl[2];         /* [flg] Is this name if each file?; files are [0] and [1] */
 
-  /* Tables *must* be sorted */
+  /* Tables must be sorted */
   (void)trv_tbl_srt(trv_tbl_1);
   (void)trv_tbl_srt(trv_tbl_2);
 
-  if(dbg_lvl_get() == nco_dbg_old){
-    (void)fprintf(stdout,"%s: INFO %s reports Sorted table 1\n",prg_nm_get(),fnc_nm);
+#ifdef NCO_HSH_TRV_OBJ
+  /* Rebuild hash table after traversal table re-ordering */
+  HASH_CLEAR(hh,trv_tbl_1->hsh);
+  HASH_CLEAR(hh,trv_tbl_2->hsh);
+  (void)nco_trv_hsh_bld(trv_tbl_1);
+  (void)nco_trv_hsh_bld(trv_tbl_2);
+#endif /* !NCO_HSH_TRV_OBJ */
+
+  if(nco_dbg_lvl_get() == nco_dbg_old){
+    (void)fprintf(stdout,"%s: INFO %s reports Sorted table 1\n",nco_prg_nm_get(),fnc_nm);
     (void)trv_tbl_prn(trv_tbl_1);
-    (void)fprintf(stdout,"%s: INFO %s reports Sorted table 2\n",prg_nm_get(),fnc_nm);
+    (void)fprintf(stdout,"%s: INFO %s reports Sorted table 2\n",nco_prg_nm_get(),fnc_nm);
     (void)trv_tbl_prn(trv_tbl_2);
-  }
+  } /* endif dbg */
 
   /* Get number of objects in each table */
   nbr_tbl_1=trv_tbl_1->nbr;
   nbr_tbl_2=trv_tbl_2->nbr;
 
   /* If both lists have names, then there are names to process */
-  flg_more_names_exist = (nbr_tbl_1>0 && nbr_tbl_2>0) ? 1 : 0;
+  flg_more_names_exist = (nbr_tbl_1 > 0 && nbr_tbl_2 > 0) ? True : False;
 
-  /* Put counters at start */
+  /* Initialize counters */
   idx_tbl_1=0;
   idx_tbl_2=0;
   idx_lst=0;
@@ -368,103 +396,80 @@ trv_tbl_mch                            /* [fnc] Match 2 tables (find common obje
   /* Store list of common objects */
   (*cmn_lst)=(nco_cmn_t *)nco_malloc((nbr_tbl_1+nbr_tbl_2)*sizeof(nco_cmn_t));
 
-  /* Iterate the 2 lists */
-  while (flg_more_names_exist)
-  {
+  /* Iterate lists */
+  while(flg_more_names_exist){
     trv_sct trv_1=trv_tbl_1->lst[idx_tbl_1];
     trv_sct trv_2=trv_tbl_2->lst[idx_tbl_2];
 
     /* Criteria is string compare */
-    nco_cmp = strcmp(trv_1.nm_fll,trv_2.nm_fll);
+    nco_cmp=strcmp(trv_1.nm_fll,trv_2.nm_fll);
 
-    /* Names match: store flag, define or write in output file, then read next names from lists */
-    if(nco_cmp == 0)
-    {
-      flg_in_fl[0]=True; 
-      flg_in_fl[1]=True;
-      (*cmn_lst)[idx_lst].flg_in_fl[0]=flg_in_fl[0]; 
-      (*cmn_lst)[idx_lst].flg_in_fl[1]=flg_in_fl[1];
+    /* Names match: store flag, define or write in output file, then read next name from lists */
+    if(!nco_cmp){
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
       (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_1.nm_fll);
       idx_lst++;
 
       idx_tbl_1++;
       idx_tbl_2++;
-
     }else if(nco_cmp < 0){
-      /* Name(1) is less than Name(2), read the next name from List 1  */
+      /* Name(1) is less than Name(2), read next name from List 1  */
 
-      flg_in_fl[0]=True; 
-      flg_in_fl[1]=False;
-      (*cmn_lst)[idx_lst].flg_in_fl[0]=flg_in_fl[0]; 
-      (*cmn_lst)[idx_lst].flg_in_fl[1]=flg_in_fl[1];
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=False;
       (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_1.nm_fll);
       idx_lst++;
 
-      if(dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_1[%d]:%s\n",prg_nm_get(),fnc_nm,idx_tbl_1,trv_1.nm_fll);
-
+      if(nco_dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_1[%d]:%s\n",nco_prg_nm_get(),fnc_nm,idx_tbl_1,trv_1.nm_fll);
       idx_tbl_1++;
     }else{
-      /* Name(1) is greater than Name(2), read the next name from List 2 */
-      flg_in_fl[0]=False; 
-      flg_in_fl[1]=True;
-      (*cmn_lst)[idx_lst].flg_in_fl[0]=flg_in_fl[0]; 
-      (*cmn_lst)[idx_lst].flg_in_fl[1]=flg_in_fl[1];
+      /* Name(1) is greater than Name(2), read next name from List 2 */
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=False;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
       (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_2.nm_fll);
       idx_lst++;
 
-      if(dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_2[%d]:%s\n",prg_nm_get(),fnc_nm,idx_tbl_2,trv_2.nm_fll);
-
+      if(nco_dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_2[%d]:%s\n",nco_prg_nm_get(),fnc_nm,idx_tbl_2,trv_2.nm_fll);
       idx_tbl_2++;
     } /* end nco_cmp */
 
-    flg_more_names_exist = (idx_tbl_1<nbr_tbl_1 && idx_tbl_2<nbr_tbl_2) ? 1 : 0;
+    flg_more_names_exist = (idx_tbl_1 < nbr_tbl_1 && idx_tbl_2 < nbr_tbl_2) ? True : False;
 
   } /* end while */
 
   /* List1 did not end */
+  if(idx_tbl_1 < nbr_tbl_1){
 
-  if(idx_tbl_1<nbr_tbl_1){
-
-    while(idx_tbl_1<nbr_tbl_1){
-      trv_sct trv_1=trv_tbl_1->lst[idx_tbl_1];
-
-      flg_in_fl[0]=True; 
-      flg_in_fl[1]=False;
-      (*cmn_lst)[idx_lst].flg_in_fl[0]=flg_in_fl[0]; 
-      (*cmn_lst)[idx_lst].flg_in_fl[1]=flg_in_fl[1];
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_1.nm_fll);
+    while(idx_tbl_1 < nbr_tbl_1){
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=False;
+      (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_tbl_1->lst[idx_tbl_1].nm_fll);
       idx_lst++;
 
-      if(dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_1[%d]:%s\n",prg_nm_get(),fnc_nm,idx_tbl_1,trv_1.nm_fll);
-
+      if(nco_dbg_lvl_get() == nco_dbg_old) (void)fprintf(stdout,"%s: INFO %s reports tbl_1[%d]:%s\n",nco_prg_nm_get(),fnc_nm,idx_tbl_1,trv_tbl_1->lst[idx_tbl_1].nm_fll);
       idx_tbl_1++;
     } /* end while */
   } /* end if */
 
   /* List2 did not end */
-  if(idx_tbl_2<nbr_tbl_2){
-    while(idx_tbl_2<nbr_tbl_2){
-      trv_sct trv_2=trv_tbl_2->lst[idx_tbl_2];
-
-      flg_in_fl[0]=False; 
-      flg_in_fl[1]=True;
-      (*cmn_lst)[idx_lst].flg_in_fl[0]=flg_in_fl[0]; 
-      (*cmn_lst)[idx_lst].flg_in_fl[1]=flg_in_fl[1];
-      (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_2.nm_fll);
+  if(idx_tbl_2 < nbr_tbl_2){
+    while(idx_tbl_2 < nbr_tbl_2){
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=False;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
+      (*cmn_lst)[idx_lst].var_nm_fll=strdup(trv_tbl_2->lst[idx_tbl_2].nm_fll);
       idx_lst++;
 
-      if(dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_2[%d]:%s\n",prg_nm_get(),fnc_nm,idx_tbl_2,trv_2.nm_fll);
-
+      if(nco_dbg_lvl_get() == nco_dbg_old)(void)fprintf(stdout,"%s: INFO %s reports tbl_2[%d]:%s\n",nco_prg_nm_get(),fnc_nm,idx_tbl_2,trv_tbl_2->lst[idx_tbl_2].nm_fll);
       idx_tbl_2++;
     } /* end while */
   } /* end if */
 
   /* Print list */
-  if(dbg_lvl_get() >= nco_dbg_var) (void)trv_tbl_cmn_nm_prt(*cmn_lst,idx_lst);
+  if(nco_dbg_lvl_get() >= nco_dbg_var) (void)trv_tbl_cmn_nm_prt(*cmn_lst,idx_lst);
 
   /* Export number of entries */
   *nbr_cmn_nm=idx_lst;
-
 } /* trv_tbl_mch() */
 
 void                          
@@ -472,7 +477,7 @@ trv_tbl_cmn_nm_prt                         /* [fnc] Print list of common objects
 (const nco_cmn_t * const cmn_lst,      /* I [sct] List of common names */
  const int nbr_cmn_nm)                 /* I [nbr] Number of common names entries */
 {
-  (void)fprintf(stdout,"%s: INFO reports common objects for both files (same absolute path)\n",prg_nm_get());
+  (void)fprintf(stdout,"%s: INFO reports common objects for both files (same absolute path)\n",nco_prg_nm_get());
   (void)fprintf(stdout,"file1     file2\n");
   (void)fprintf(stdout,"---------------------------------------\n");
   for(int idx=0;idx<nbr_cmn_nm;idx++){
@@ -505,17 +510,14 @@ nco_dmn_trv_sct                       /* [fnc] Return unique dimension object fr
  const trv_tbl_sct * const trv_tbl)   /* I [sct] GTT (Group Traversal Table) */
 {
   /* Search table dimension list and compare IDs */
-  for(unsigned int idx_dmn=0;idx_dmn<trv_tbl->nbr_dmn;idx_dmn++){
-    if(dmn_id == trv_tbl->lst_dmn[idx_dmn].dmn_id){
+  for(unsigned int idx_dmn=0;idx_dmn<trv_tbl->nbr_dmn;idx_dmn++)
+    if(dmn_id == trv_tbl->lst_dmn[idx_dmn].dmn_id)
       return &trv_tbl->lst_dmn[idx_dmn];
-    }
-  }
 
   assert(0);
   return NULL;
 } /* nco_dmn_trv_sct() */
 
-
 void                                  
 nco_dmn_set_msa                       /* [fnc] Update dimension with hyperslabbed size */
 (const int dmn_id,                    /* I [id] Unique dimension ID */
@@ -523,28 +525,256 @@ nco_dmn_set_msa                       /* [fnc] Update dimension with hyperslabbe
  const trv_tbl_sct *trv_tbl)          /* I/O [sct] GTT (Group Traversal Table) */
 {
   /* Search table dimension list and compared IDs */
-  for(unsigned int dmn_idx=0;dmn_idx<trv_tbl->nbr_dmn;dmn_idx++){
-    if(dmn_id == trv_tbl->lst_dmn[dmn_idx].dmn_id){
+  for(unsigned int dmn_idx=0;dmn_idx<trv_tbl->nbr_dmn;dmn_idx++)
+    if(dmn_id == trv_tbl->lst_dmn[dmn_idx].dmn_id)
       trv_tbl->lst_dmn[dmn_idx].lmt_msa.dmn_cnt=dmn_cnt;
-    }
-  }
 
   return;
 } /* nco_dmn_set_msa() */
 
-long                                  /* O hyperslabbed size */
+long                                  /* O [nbr] Hyperslabbed size */
 nco_dmn_get_msa                       /* [fnc] Update dimension with hyperslabbed size */
 (const int dmn_id,                    /* I [id] Unique dimension ID */
  const trv_tbl_sct *trv_tbl)          /* I/O [sct] GTT (Group Traversal Table) */
 {
-
   /* Search table dimension list and compare IDs */
-  for(unsigned int dmn_idx=0;dmn_idx<trv_tbl->nbr_dmn;dmn_idx++){
-    if(dmn_id == trv_tbl->lst_dmn[dmn_idx].dmn_id){
+  for(unsigned int dmn_idx=0;dmn_idx<trv_tbl->nbr_dmn;dmn_idx++)
+    if(dmn_id == trv_tbl->lst_dmn[dmn_idx].dmn_id)
       return trv_tbl->lst_dmn[dmn_idx].lmt_msa.dmn_cnt;
-    }
-  }
      
   assert(0);
   return -1;
 } /* nco_dmn_get_msa() */
+
+void
+nco_trv_hsh_del /* Delete hash table */
+(trv_tbl_sct * const trv_tbl) /* I/O [sct] Traversal table */
+{
+  /* Purpose: Delete hash table
+     http://troydhanson.github.io/uthash/userguide.html#_delete_item */
+  trv_sct *trv_obj; /* [sct] GTT object structure */
+  trv_sct *hsh_tmp; /* [sct] GTT object structure */
+
+  /* Iterate over hash table */
+  HASH_ITER(hh,trv_tbl->hsh,trv_obj,hsh_tmp){
+    /* Delete current object */
+    HASH_DEL(trv_tbl->hsh,trv_obj);
+  } /* end iteration over hash table */  
+
+} /* nco_trv_hsh_del() */
+
+void
+nco_trv_hsh_bld /* Hash traversal table for fastest access */
+(trv_tbl_sct * const trv_tbl) /* I/O [sct] Traversal table */
+{
+  /* Purpose: Hash all objects in traversal table and store resultant hash table */
+
+  /* Notes on Hash vs. Other methods:
+     Usually we wish to find and return object with same full name
+     Full names are guaranteed to unique in netCDF4/HDF5 files
+     The two practical methods are:
+     
+     1. Bruit-force search with loop/strcmp(): (old method)
+     No initial setup necessary
+     Loop through traversal table, use strcmp() to find matching name
+     This method works if traversal table is re-ordered or names change after keys are generated
+     Time-expense of bruit-force searches is O(n)
+     This method is therefore more robust yet much slower than hashes
+     2. Hash table: (new method)
+     Add each object to hash table on creation by calling nco_trv_hsh_bld() from nco_blr_trv_tbl()
+     This generates hash table as string-keyed hash with object's full-name as key
+     Then, as needed, pass key to hash table to retrieve desired object
+     This method does not depend on traversal table remaining in same order as when keys were generated
+     But it does require that no names change after keys are generated
+     More specifically, it requires old hash entries be deleted and new ones added when keys change
+     Time-expense of hashes is O(1+n/k)
+     Hashes are therefore more fragile yet much quicker than bruit-force searches
+     Care must be used to destroy/replace/re-create hash table entries if when keys change (or table is re-ordered)
+
+     Hash table lookups:
+     trv_sct *trv_obj;
+     HASH_FIND_STR(trv_tbl->hsh,nm_fll,trv_obj);
+     return trv_obj;
+     Input key argument (nm_fll field) is unchanged
+     However, HASH_FIND_STR() macro treats key as (i.e., casts it to) unsigned bytes internally
+     Hence  -Wcast_qual causes compiler complaint if key argument is const char * const nm_fll
+     Potential workarounds:
+     1. Eliminate -Wcast_qual from compiler settings
+        Verified this works
+     2. Change function prototype to non-const key
+        This eliminates compiler warnings at cost of introducing non-typesafe code paths
+	Move all hash-lookup functions into single file that does not get -Wcast_qual?
+     3. Pass key as void pointer?
+        Not sure this is doable/would work
+     4. Duplicate then free() key for each hash-lookup
+        Verified this works yet it seems too expensive, e.g., 
+        char *hsh_key=(char *)strdup(nm_fll);
+        HASH_FIND_STR(trv_tbl->hsh,hsh_key,trv_obj);
+        if(hsh_key) hsh_key=(char *)nco_free(hsh_key); */
+
+  /* NB: Hash table must be NULL-initialized */
+  trv_tbl->hsh=NULL;
+
+  for(unsigned int tbl_idx=0;tbl_idx<trv_tbl->nbr;tbl_idx++){
+    /* Key is full object name but do not use nm_fll itself as key
+       That would be unsafe because of dangling pointer to nm_fll
+       Instead duplicate nm_fll into its own hsh_key field
+       Release this hsh_key memory in trv_tbl_free() */
+    trv_tbl->lst[tbl_idx].hsh_key=strdup(trv_tbl->lst[tbl_idx].nm_fll);
+    /* General macro faster than convenience macro since can use GTT-supplied string length */
+    HASH_ADD_KEYPTR(hh,trv_tbl->hsh,trv_tbl->lst[tbl_idx].hsh_key,trv_tbl->lst[tbl_idx].nm_fll_lng,trv_tbl->lst+tbl_idx);
+    /* Convenience macro (more expensive because UTHASH must compute key-length itself?) */
+    //    HASH_ADD_PTR(trv_tbl->hsh,trv_tbl->lst[tbl_idx].hsh_key,trv_tbl->lst+tbl_idx);
+  } /* end loop over trv_tbl */
+
+} /* end trv_tbl_hsh() */
+
+
+void 
+nco_nm_srt                             /* [fnc] Sort traversal table */
+(char **nm_lst,                        /* I [sng] List of names */
+ const int nm_lst_nbr)                 /* I [nbr] Number of items in list */
+{
+  /* Purpose: Sort list of strings  */
+  qsort(nm_lst,(size_t)nm_lst_nbr,sizeof(char **),nco_cmp_sng);
+} /* end nco_nm_srt() */
+
+void                          
+nco_nm_mch                             /* [fnc] Match 2 lists of strings and mark common strings  */
+(char **nm_lst_1,                      /* I [sng] List of names */
+ const int nm_lst_1_nbr,               /* I [nbr] Number of items in list */
+ char **nm_lst_2,                      /* I [sng] List of names */
+ const int nm_lst_2_nbr,               /* I [nbr] Number of items in list */
+ nco_cmn_t **cmn_lst,                  /* I/O [sct] List of all names */
+ int * nbr_nm,                         /* I/O [nbr] Number of all names (size of above array) */
+ int * nbr_cmn_nm)                     /* I/O [nbr] Number of common names */
+{
+  /* Purpose: Match 2 lists of strings and export common strings. 
+  Use cosequential match algorithm described in
+  Folk, Michael; Zoellick, Bill. (1992). File Structures. Addison-Wesley.
+
+  Compare 2 ordered lists of names:
+  if Name(1) is less than Name(2), read next name from List 1; this is done by incrementing current index
+  if Name(1) is greater than Name(2), read next name from List 2
+  if names are identical, read next names from both lists  */
+
+  const char fnc_nm[]="nco_nm_mch()"; /* [sng] Function name */
+
+  int idx_lst;                   /* [idx] Current position in common List */ 
+  int idx_tbl_1;                 /* [idx] Current position in List 1 */ 
+  int idx_tbl_2;                 /* [idx] Current position in List 2 */ 
+  int nbr_tbl_1;                 /* [nbr] Number of items in list 1 */
+  int nbr_tbl_2;                 /* [nbr] Number of items in list 2 */
+  int nco_cmp;                   /* [nbr] Return value of strcmp() */            
+
+  nco_bool flg_more_names_exist; /* [flg] Are there more names to process? */
+
+  /* Names must be sorted */
+  (void)nco_nm_srt(nm_lst_1,nm_lst_1_nbr);
+  (void)nco_nm_srt(nm_lst_2,nm_lst_2_nbr);
+
+  /* Get number of objects in each table */
+  nbr_tbl_1=nm_lst_1_nbr;
+  nbr_tbl_2=nm_lst_2_nbr;
+
+  /* If both lists have names, then there are names to process */
+  flg_more_names_exist = (nbr_tbl_1 > 0 && nbr_tbl_2 > 0) ? True : False;
+
+  /* Store list of common objects */
+  (*cmn_lst)=(nco_cmn_t *)nco_malloc((nbr_tbl_1+nbr_tbl_2)*sizeof(nco_cmn_t));
+
+  /* Initialize counters and output */
+  *nbr_cmn_nm=0;
+  *nbr_nm=0;
+  idx_tbl_1=0;
+  idx_tbl_2=0;
+  idx_lst=0;
+
+  /* Iterate lists */
+  while(flg_more_names_exist){
+    char *nm_1=nm_lst_1[idx_tbl_1];
+    char *nm_2=nm_lst_2[idx_tbl_2];
+
+    /* Criteria is string compare */
+    nco_cmp=strcmp(nm_1,nm_2);
+
+    /* Names match: store flag, define or write in output file, then read next name from lists */
+    if(!nco_cmp){
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
+      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_1);
+      idx_lst++;
+      idx_tbl_1++;
+      idx_tbl_2++;
+      /* Export commnon names */
+      *nbr_cmn_nm=idx_lst;
+    }else if(nco_cmp < 0){
+      /* Name(1) is less than Name(2), read next name from List 1  */
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=False;
+      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_1);
+      idx_lst++; 
+      idx_tbl_1++;
+    }else{
+      /* Name(1) is greater than Name(2), read next name from List 2 */
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=False;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
+      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_2);
+      idx_lst++;   
+      idx_tbl_2++;
+    } /* end nco_cmp */
+
+    flg_more_names_exist = (idx_tbl_1 < nbr_tbl_1 && idx_tbl_2 < nbr_tbl_2) ? True : False;
+
+  } /* end while */
+
+  /* List1 did not end */
+  if(idx_tbl_1 < nbr_tbl_1){
+
+    while(idx_tbl_1 < nbr_tbl_1){
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=True;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=False;
+      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_lst_1[idx_tbl_1]);
+      idx_lst++;
+      idx_tbl_1++;
+    } /* end while */
+  } /* end if */
+
+  /* List2 did not end */
+  if(idx_tbl_2 < nbr_tbl_2){
+    while(idx_tbl_2 < nbr_tbl_2){
+      (*cmn_lst)[idx_lst].flg_in_fl[0]=False;
+      (*cmn_lst)[idx_lst].flg_in_fl[1]=True;
+      (*cmn_lst)[idx_lst].var_nm_fll=strdup(nm_lst_2[idx_tbl_2]);
+      idx_lst++;
+      idx_tbl_2++;
+    } /* end while */
+  } /* end if */
+
+  /* Export number of entries */
+  *nbr_nm=idx_lst;
+
+} /* nco_nm_mch() */
+
+void
+trv_tbl_mrk_nsm_mb                    /* [fnc] Mark ensemble member flag in table for "var_nm_fll" */
+(const char * const var_nm_fll,       /* I [sng] Variable name to find */
+ const nco_bool flg_nsm_tpl,          /* I [flg] Variable is template member */
+ const char * const grp_nm_fll_prn,   /* I [sng] Parent group full name (key for ensemble) */
+ const trv_tbl_sct * const trv_tbl)   /* I [sct] Traversal table */
+{
+#ifdef NCO_HSH_TRV_OBJ
+  trv_sct *trv_obj; /* [sct] GTT object structure */
+  HASH_FIND_STR(trv_tbl->hsh,var_nm_fll,trv_obj);
+  if(trv_obj) trv_obj->flg_nsm_mbr=True;
+#else /* !NCO_HSH_TRV_OBJ */
+  for(unsigned uidx=0;uidx<trv_tbl->nbr;uidx++)
+    if(strcmp(var_nm_fll,trv_tbl->lst[uidx].nm_fll) == 0){
+      trv_tbl->lst[uidx].flg_nsm_mbr=True;
+      trv_tbl->lst[uidx].nsm_nm=strdup(grp_nm_fll_prn);
+      if (flg_nsm_tpl) trv_tbl->lst[uidx].flg_nsm_tpl=True;
+    }
+#endif /* !NCO_HSH_TRV_OBJ */
+
+  return;
+} /* end trv_tbl_mrk_nsm_mb() */
\ No newline at end of file
