@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.h,v 1.90 2013/09/06 22:30:36 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_trv.h,v 1.97 2013/11/06 01:37:17 pvicente Exp $ */
 
 /* Purpose: netCDF4 traversal storage */
 
@@ -80,7 +80,6 @@ trv_tbl_mrk_prc_fix                    /* [fnc] Mark fixed/processed flag in tab
  prc_typ_enm typ_prc,                  /* I [enm] Processing type */
  const trv_tbl_sct * const trv_tbl);   /* I [sct] Traversal table */
 
-
 void 
 trv_tbl_prn_xtr                        /* [fnc] Print extraction flag of traversal table */
 (const trv_tbl_sct * const trv_tbl,    /* I [sct] Traversal table */
@@ -106,7 +105,6 @@ trv_tbl_cmn_nm_prt                     /* [fnc] Print list of common objects (sa
 (const nco_cmn_t * const cmn_lst,      /* I [sct] List of common names */
  const int nbr_cmn_nm);                /* I [nbr] Number of common names entries */
 
-
 dmn_trv_sct *                         /* O [sct] GTT dimension structure (stored in *groups*) */
 nco_dmn_trv_sct                       /* [fnc] Return unique dimension object from unique ID */
 (const int dmn_id,                    /* I [id] Unique dimension ID */
@@ -123,5 +121,34 @@ nco_dmn_get_msa                       /* [fnc] Update dimension with hyperslabbe
 (const int dmn_id,                    /* I [id] Unique dimension ID */
  const trv_tbl_sct *trv_tbl);         /* I/O [sct] GTT (Group Traversal Table) */
 
+void 
+nco_trv_hsh_bld                       /* Hash traversal table for fastest access */
+(trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
+
+void
+nco_trv_hsh_del                       /* Delete hash table */
+(trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
+
+void 
+nco_nm_srt                             /* [fnc] Sort traversal table */
+(char **nm_lst,                        /* I [sng] List of names */
+ const int nm_lst_nbr);                /* I [nbr] Number of items in list */
+
+void                          
+nco_nm_mch                             /* [fnc] Match 2 lists of strings and mark common strings  */
+(char **nm_lst_1,                      /* I [sng] List of names */
+ const int nm_lst_1_nbr,               /* I [nbr] Number of items in list */
+ char **nm_lst_2,                      /* I [sng] List of names */
+ const int nm_lst_2_nbr,               /* I [nbr] Number of items in list */
+ nco_cmn_t **cmn_lst,                  /* I/O [sct] List of all names */
+ int * nbr_nm,                         /* I/O [nbr] Number of all names (size of above array) */
+ int * nbr_cmn_nm);                    /* I/O [nbr] Number of common names */
+
+void
+trv_tbl_mrk_nsm_mb                    /* [fnc] Mark ensemble member flag in table for "var_nm_fll" */
+(const char * const var_nm_fll,       /* I [sng] Variable name to find */
+ const nco_bool flg_nsm_tpl,          /* I [flg] Variable is template member */
+ const char * const grp_nm_fll_prn,   /* I [sng] Parent group full name (key for ensemble) */
+ const trv_tbl_sct * const trv_tbl);  /* I [sct] Traversal table */
 
 #endif /* NCO_GRP_TRV_H */
