@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.391 2013/10/16 06:54:17 pvicente Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_grp_utl.h,v 1.403 2013/11/02 22:35:27 pvicente Exp $ */
 
 /* Purpose: Group utilities */
 
@@ -248,6 +248,7 @@ nco_crd_var_dmn_scp                   /* [fnc] Is coordinate variable in dimensi
 int                                    /* [rcd] Return code */
 nco_grp_itr                            /* [fnc] Populate traversal table by examining, recursively, subgroups of parent */
 (const int grp_id,                     /* I [ID] Group ID */
+ char * const grp_nm_fll_prn,          /* I [sng] Absolute group name of parent (path) */
  char * const grp_nm_fll,              /* I [sng] Absolute group name (path) */
  trv_tbl_sct * const trv_tbl);         /* I/O [sct] GTT (Group Traversal Table) */
 
@@ -384,7 +385,7 @@ nco_cpy_fix                            /* [fnc] Copy processing type fixed objec
 
 nco_bool                               /* O [flg] Copy packing attributes */
 nco_pck_cpy_att                        /* [fnc] Inquire about copying packing attributes  */
-(const int prg_id,                     /* I [enm] Program ID */
+(const int nco_prg_id,                     /* I [enm] Program ID */
  const int nco_pck_plc,                /* I [enm] Packing policy */
  const var_sct * const var_prc);       /* I [sct] Variable */
 
@@ -504,12 +505,6 @@ nco_var_prc_idx_trv                   /* [fnc] Find index of processed variable
  const int nbr_var_prc,               /* I [nbr] Number of processed variables */
  int * var_prc_idx_out);              /* O [nbr] Number of dimension to re-order */
 
-nm_id_sct *                           /* O [sct] Dimension list */
-nco_dmn_lst_mk_trv                    /* [fnc] Attach dimension IDs to dimension list */
-(char **dmn_lst_in,                   /* I [sng] User-specified list of dimension names */
- const int nbr_dmn,                   /* I [nbr] Total number of dimensions in list */
- const trv_tbl_sct * const trv_tbl);  /* I [sct] GTT (Group Traversal Table) */
-
 void
 nco_aed_prc_trv                       /* [fnc] Process single attribute edit for single variable (GTT) */
 (const int nc_id,                     /* I [id] Input netCDF file ID */
@@ -641,6 +636,48 @@ nco_obj_usr_sng                       /* [fnc] Parse input string and return tab
  const trv_tbl_sct * const trv_tbl,   /* I [lst] Traversal table */ 
  nco_bool *is_opt);                   /* O [flg] Dimension presence is optional (input string has '.') */
 
+void                                  
+nco_aed_prc_grp                       /* [fnc] Process attributes in groups */
+(const int nc_id,                     /* I [id] netCDF file ID */
+ const aed_sct aed,                   /* I [sct] Structure containing information necessary to edit */
+ const trv_tbl_sct * const trv_tbl);  /* I [lst] Traversal table */ 
+
+void                                  
+nco_aed_prc_glb                       /* [fnc] Process attributes in root group */
+(const int nc_id,                     /* I [id] netCDF file ID */
+ const aed_sct aed,                   /* I [sct] Structure containing information necessary to edit */
+ const trv_tbl_sct * const trv_tbl);  /* I [lst] Traversal table */ 
+
+void                                  
+nco_aed_prc_var                       /* [fnc] Process attributes in variables */
+(const int nc_id,                     /* I [id] netCDF file ID */
+ const aed_sct aed,                   /* I [sct] Structure containing information necessary to edit */
+ const trv_tbl_sct * const trv_tbl);  /* I [lst] Traversal table */ 
+
+void                                  
+nco_aed_prc_var_xtr                   /* [fnc] Process attributes in variables that match table extraction flag */
+(const int nc_id,                     /* I [id] netCDF file ID */
+ const aed_sct aed,                   /* I [sct] Structure containing information necessary to edit */
+ const trv_tbl_sct * const trv_tbl);  /* I [lst] Traversal table */ 
+
+void                                  
+nco_aed_prc_var_nm                    /* [fnc] Process attributes in variables that match input name */
+(const int nc_id,                     /* I [id] netCDF file ID */
+ const aed_sct aed,                   /* I [sct] Structure containing information necessary to edit */
+ const trv_tbl_sct * const trv_tbl);  /* I [lst] Traversal table */ 
+
+void
+nco_bld_nsm                           /* [fnc] Build ensembles */
+(const int nc_id,                     /* I [id] netCDF file ID */
+ trv_tbl_sct * const trv_tbl);        /* I/O [sct] Traversal table */
+
+void                                    
+nco_grp_var_lst                        /* [fnc] Export list of variable names for group */
+(const int nc_id,                      /* I [id] netCDF file ID */
+ const char * const grp_nm_fll,        /* I [sng] Absolute group name */
+ char ***nm_lst,                       /* I/O [sng] List of names */
+ int *nm_lst_nbr);                     /* I/O [nbr] Number of items in list */
+
 
 #ifdef __cplusplus
 } /* end extern "C" */
