@@ -1,8 +1,8 @@
-/* $Header: /cvsroot/nco/nco/src/nco/nco_rth_utl.h,v 1.25 2012/01/01 20:51:53 zender Exp $ */
+/* $Header: /cvsroot/nco/nco/src/nco/nco_rth_utl.h,v 1.37 2013/09/19 03:35:18 pvicente Exp $ */
 
 /* Purpose: Arithmetic controls and utilities */
 
-/* Copyright (C) 1995--2012 Charlie Zender
+/* Copyright (C) 1995--2013 Charlie Zender
    License: GNU General Public License (GPL) Version 3
    See http://www.gnu.org/copyleft/gpl.html for full license text */
 
@@ -16,8 +16,13 @@
 #include <math.h> /* sin cos cos sin 3.14159 */
 #include <stdio.h> /* stderr, FILE, NULL, printf */
 #include <stdlib.h> /* strtod, strtol, malloc, getopt, exit */
-#include <string.h> /* strcmp. . . */
-#include <unistd.h> /* POSIX stuff */
+#include <string.h> /* strcmp() */
+#ifndef _MSC_VER
+# include <unistd.h> /* POSIX stuff */
+#endif /* !_MSC_VER */
+#ifdef _OPENMP
+# include <omp.h> /* OpenMP pragmas */
+#endif /* !_OPENMP */
 
 /* 3rd party vendors */
 #include <netcdf.h> /* netCDF definitions and C library */
@@ -28,6 +33,9 @@
 #include "nco_cnf_typ.h" /* Conform variable types */
 #include "nco_ctl.h" /* Program flow control functions */
 #include "nco_mmr.h" /* Memory management */
+#ifdef _MSC_VER
+# include "nco_rth_flt.h" /* Float-precision arithmetic, MSVC macros */
+#endif /* !_MSC_VER */
 #include "nco_var_utl.h" /* Variable utilities */
 #include "nco_var_rth.h" /* Variable arithmetic */
 
@@ -39,9 +47,19 @@ int /* O [enm] Arithmetic operation */
 nco_op_typ_get /* [fnc] Convert user-specified operation into operation key */
 (const char * const nco_op_sng); /* I [sng] User-specified operation */
 
+void 
+nco_opr_nrm /* [fnc] Normalization of arithmetic operations for ncra/ncea */
+(const int nco_op_typ, /* I [enm] Operation type */
+ const int nbr_var_prc, /* I [nbr] Number of processed variables */
+ X_CST_PTR_CST_PTR_Y(var_sct,var_prc), /* I [sct] Variables in input file */
+ X_CST_PTR_CST_PTR_Y(var_sct,var_prc_out), /* I/O [sct] Variables in output file */
+ const nco_bool flg_nrm, /* I [flg] This record needs normalization */
+ const char * const rec_nm_fll,      /* I [sng] Full name of record being done in loop (trv_tbl->lmt_rec[idx_rec]->nm_fll ) */
+ const trv_tbl_sct * const trv_tbl); /* I [sct] Traversal table */
+
 void 
 nco_opr_drv /* [fnc] Intermediate control of arithmetic operations for ncra/ncea */
-(const long idx_rec, /* I [idx] Index of current record */
+(const long idx_rec, /* I [idx] Index of record (ncra) or file (ncea) in current operation group */
  const int nco_op_typ, /* I [enm] Operation type */
  const var_sct * const var_prc, /* I [sct] Variable in input file */
  var_sct * const var_prc_out); /* I/O [sct] Variable in output file */
